@@ -207,7 +207,7 @@ mod test {
             "world" => 2,
         };
 
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         {
             let mut wg = table.write();
             wg.insert("hello", 1);
@@ -222,7 +222,7 @@ mod test {
 
     #[test]
     fn clear() {
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         {
             let mut wg = table.write();
             wg.insert("hello", 1);
@@ -241,7 +241,7 @@ mod test {
             "hello" => 1,
         };
 
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         {
             let mut wg = table.write();
             wg.insert("hello", 1);
@@ -261,7 +261,7 @@ mod test {
             "hello" => 1,
         };
 
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         {
             let mut wg = table.write();
             wg.insert("hello", 1);
@@ -277,7 +277,7 @@ mod test {
 
     #[test]
     fn shrink_to_fit_and_reserve() {
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         let initial_capacity;
         let additional = 10;
         {
@@ -302,7 +302,7 @@ mod test {
             "world" => 0,
             "my" => 2
         };
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         {
             let mut wg = table.write();
             wg.insert("hello", 1);
@@ -327,7 +327,7 @@ mod test {
             "world" => 1,
         };
 
-        let mut table = AsLockHandle::<&str, i32>::default();
+        let table = AsLockHandle::<&str, i32>::default();
         {
             let mut wg = table.write();
             wg.insert("hello", 1);
